@@ -1770,9 +1770,9 @@ def trplot(T, axes=None, block=True, dims=None, color='blue', frame=None,   # py
 
     # create unit vectors in homogeneous form
     o = T @ np.array([0, 0, 0, 1])
-    x = T @ np.array([1, 0, 0, 1]) * length
-    y = T @ np.array([0, 1, 0, 1]) * length
-    z = T @ np.array([0, 0, 1, 1]) * length
+    x = T @ np.array([length, 0, 0, 1])
+    y = T @ np.array([0, length, 0, 1])
+    z = T @ np.array([0, 0, length, 1])
 
     # draw the axes
 
